- logFileSample
character , options are: recent download the most recent logfile, all downloads all logfiles, or a plain number e.g. 2 for a specific logfile. Note the telemetry logfiles are numbering from 1 to 9 only, the most recent one is not numbered. The binary logfiles from the pixhawk are numbering continously but only the last 50 files or so will exist.
- logSource
character, options are: rc = logfiles from the radio control, pixhawk = logfiles from the flightcontroller, default is set to rc. The radio control is providing the last ten telemetry data files, while the flight controller provides the latest 50 binary logfiles.
- logDest
character (existing) destination path to which the logs should be downloaded to
- downloadOnly
logical wether to only download the files or also convert and rename them, default is set FALSE
- netWarn
logical wether to warn and waits before starting a connection to the controller. helps while testing due to occassional wifi shutdowns of the Solo, default is set to FALSE
- renameFiles
logical renames the log and gpx files according to the time period, default is set TRUE
- makeSP
logical wether returning an sp object from the gpx files or not, default is FALSE